Hello community,

here is the log from the commit of package unrar for openSUSE:Factory:NonFree 
checked in at 2019-09-30 16:03:36
++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
Comparing /work/SRC/openSUSE:Factory:NonFree/unrar (Old)
 and      /work/SRC/openSUSE:Factory:NonFree/.unrar.new.2352 (New)
++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++

Package is "unrar"

Mon Sep 30 16:03:36 2019 rev:82 rq:733670 version:5.8.2

Changes:
--------
--- /work/SRC/openSUSE:Factory:NonFree/unrar/unrar.changes      2019-09-02 
13:26:57.193294319 +0200
+++ /work/SRC/openSUSE:Factory:NonFree/.unrar.new.2352/unrar.changes    
2019-09-30 16:03:47.784514453 +0200
@@ -1,0 +2,6 @@
+Fri Sep 27 11:30:14 UTC 2019 - Ismail Dönmez <[email protected]>
+
+- Update to version 5.8.2
+  * Based on WinRAR version 5.80 beta 2
+
+-------------------------------------------------------------------

Old:
----
  unrarsrc-5.8.1.tar.gz

New:
----
  unrarsrc-5.8.2.tar.gz

++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++

Other differences:
------------------
++++++ unrar.spec ++++++
--- /var/tmp/diff_new_pack.Psif68/_old  2019-09-30 16:03:49.700509354 +0200
+++ /var/tmp/diff_new_pack.Psif68/_new  2019-09-30 16:03:49.704509344 +0200
@@ -18,10 +18,10 @@
 
 # majorversion should match the major version number.
 %define majorversion 5
-%define libsuffix 5_8_1
+%define libsuffix 5_8_2
 
 Name:           unrar
-Version:        5.8.1
+Version:        5.8.2
 Release:        0
 Summary:        A program to extract, test, and view RAR archives
 License:        NonFree

++++++ unrarsrc-5.8.1.tar.gz -> unrarsrc-5.8.2.tar.gz ++++++
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' 
'--exclude=.svnignore' old/unrar/arcread.cpp new/unrar/arcread.cpp
--- old/unrar/arcread.cpp       2019-08-29 22:34:42.000000000 +0200
+++ new/unrar/arcread.cpp       2019-09-26 10:35:32.000000000 +0200
@@ -1256,8 +1256,9 @@
     Raw.Read(NameSize);
 
     char FileName[NM];
-    Raw.GetB((byte *)FileName,Min(NameSize,ASIZE(FileName)));
-    FileName[NameSize]=0;
+    size_t ReadNameSize=Min(NameSize,ASIZE(FileName)-1);
+    Raw.GetB((byte *)FileName,ReadNameSize);
+    FileName[ReadNameSize]=0;
     IntToExt(FileName,FileName,ASIZE(FileName));
     CharToWide(FileName,FileHead.FileName,ASIZE(FileHead.FileName));
     ConvertNameCase(FileHead.FileName);
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' 
'--exclude=.svnignore' old/unrar/dll.rc new/unrar/dll.rc
--- old/unrar/dll.rc    2019-08-29 21:35:30.000000000 +0200
+++ new/unrar/dll.rc    2019-09-26 09:37:12.000000000 +0200
@@ -2,8 +2,8 @@
 #include <commctrl.h>
 
 VS_VERSION_INFO VERSIONINFO
-FILEVERSION 5, 80, 1, 3169
-PRODUCTVERSION 5, 80, 1, 3169
+FILEVERSION 5, 80, 2, 3196
+PRODUCTVERSION 5, 80, 2, 3196
 FILEOS VOS__WINDOWS32
 FILETYPE VFT_APP
 {
@@ -14,8 +14,8 @@
       VALUE "CompanyName", "Alexander Roshal\0"
       VALUE "ProductName", "RAR decompression library\0"
       VALUE "FileDescription", "RAR decompression library\0"
-      VALUE "FileVersion", "5.80.1\0"
-      VALUE "ProductVersion", "5.80.1\0"
+      VALUE "FileVersion", "5.80.2\0"
+      VALUE "ProductVersion", "5.80.2\0"
       VALUE "LegalCopyright", "Copyright � Alexander Roshal 1993-2019\0"
       VALUE "OriginalFilename", "Unrar.dll\0"
     }
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' 
'--exclude=.svnignore' old/unrar/errhnd.cpp new/unrar/errhnd.cpp
--- old/unrar/errhnd.cpp        2019-08-29 22:34:43.000000000 +0200
+++ new/unrar/errhnd.cpp        2019-09-26 10:35:33.000000000 +0200
@@ -328,7 +328,7 @@
 
 bool ErrorHandler::GetSysErrMsg(wchar *Msg,size_t Size)
 {
-#if !defined(SFX_MODULE) && !defined(SILENT)
+#ifndef SILENT
 #ifdef _WIN_ALL
   int ErrType=GetLastError();
   if (ErrType!=0)
@@ -361,7 +361,7 @@
     return;
 #ifdef _WIN_ALL
   wchar *CurMsg=Msg;
-  while (CurMsg!=NULL)
+  while (CurMsg!=NULL) // Print string with \r\n as several strings to 
multiple lines.
   {
     while (*CurMsg=='\r' || *CurMsg=='\n')
       CurMsg++;
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' 
'--exclude=.svnignore' old/unrar/extract.cpp new/unrar/extract.cpp
--- old/unrar/extract.cpp       2019-08-29 22:34:43.000000000 +0200
+++ new/unrar/extract.cpp       2019-09-26 10:35:33.000000000 +0200
@@ -624,7 +624,6 @@
         CurFile.Prealloc(Arc.FileHead.UnpSize);
         Preallocated=Arc.FileHead.UnpSize;
       }
-
       CurFile.SetAllowDelete(!Cmd->KeepBroken);
 
       bool FileCreateMode=!TestMode && !SkipSolid && Command!='P';
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' 
'--exclude=.svnignore' old/unrar/os.hpp new/unrar/os.hpp
--- old/unrar/os.hpp    2019-08-29 22:34:43.000000000 +0200
+++ new/unrar/os.hpp    2019-09-26 10:35:33.000000000 +0200
@@ -133,7 +133,7 @@
 
 #ifdef _UNIX
 
-#define  NM  2048
+#define NM  2048
 
 #include <unistd.h>
 #include <sys/types.h>
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' 
'--exclude=.svnignore' old/unrar/rar.hpp new/unrar/rar.hpp
--- old/unrar/rar.hpp   2019-08-29 22:34:43.000000000 +0200
+++ new/unrar/rar.hpp   2019-09-26 10:35:33.000000000 +0200
@@ -77,6 +77,9 @@
 
 #include "rs.hpp"
 #include "rs16.hpp"
+
+
+
 #include "recvol.hpp"
 #include "volume.hpp"
 #include "smallfn.hpp"
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' 
'--exclude=.svnignore' old/unrar/rdwrfn.hpp new/unrar/rdwrfn.hpp
--- old/unrar/rdwrfn.hpp        2019-08-29 22:34:43.000000000 +0200
+++ new/unrar/rdwrfn.hpp        2019-09-26 10:35:33.000000000 +0200
@@ -3,6 +3,7 @@
 
 class CmdAdd;
 class Unpack;
+class ArcFileSearch;
 
 #if 0
 // We use external i/o calls for Benchmark command.
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' 
'--exclude=.svnignore' old/unrar/system.cpp new/unrar/system.cpp
--- old/unrar/system.cpp        2019-08-29 22:34:44.000000000 +0200
+++ new/unrar/system.cpp        2019-09-26 10:35:34.000000000 +0200
@@ -188,7 +188,9 @@
 {
   int CPUInfo[4];
   __cpuid(CPUInfo, 0x80000000);
-  uint MaxSupported=CPUInfo[0] & 0x7fffffff;  // Maximum supported cpuid 
function.
+
+  // Maximum supported cpuid function. For example, Pentium M 755 returns 4 
here.
+  uint MaxSupported=CPUInfo[0] & 0x7fffffff;
 
   if (MaxSupported>=7)
   {
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' 
'--exclude=.svnignore' old/unrar/version.hpp new/unrar/version.hpp
--- old/unrar/version.hpp       2019-08-29 22:34:44.000000000 +0200
+++ new/unrar/version.hpp       2019-09-26 10:35:34.000000000 +0200
@@ -1,6 +1,6 @@
 #define RARVER_MAJOR     5
 #define RARVER_MINOR    80
-#define RARVER_BETA      1
-#define RARVER_DAY      30
-#define RARVER_MONTH     8
+#define RARVER_BETA      2
+#define RARVER_DAY      26
+#define RARVER_MONTH     9
 #define RARVER_YEAR   2019


Reply via email to
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' 
'--exclude=.svnignore' old/unrar/unicode.cpp new/unrar/unicode.cpp
--- old/unrar/unicode.cpp       2019-08-29 22:34:44.000000000 +0200
+++ new/unrar/unicode.cpp       2019-09-26 10:35:34.000000000 +0200
@@ -489,6 +489,8 @@
 wchar* wcslower(wchar *s)
 {
 #ifdef _WIN_ALL
+  // _wcslwr requires setlocale and we do not want to depend on setlocale
+  // in Windows. Also CharLower involves less overhead.
   CharLower(s);
 #else
   for (wchar *c=s;*c!=0;c++)
@@ -503,6 +505,8 @@
 wchar* wcsupper(wchar *s)
 {
 #ifdef _WIN_ALL
+  // _wcsupr requires setlocale and we do not want to depend on setlocale
+  // in Windows. Also CharUpper involves less overhead.
   CharUpper(s);
 #else
   for (wchar *c=s;*c!=0;c++)
@@ -520,8 +524,9 @@
 #if defined(_WIN_ALL)
   // CharUpper is more reliable than towupper in Windows, which seems to be
   // C locale dependent even in Unicode version. For example, towupper failed
-  // to convert lowercase Russian characters.
-  return (int)(INT_PTR)CharUpper((wchar *)(INT_PTR)ch);
+  // to convert lowercase Russian characters. Use 0xffff mask to prevent crash
+  // if value larger than 0xffff is passed to this function.
+  return (int)(INT_PTR)CharUpper((wchar *)(INT_PTR)(ch&0xffff));
 #else
   return towupper(ch);
 #endif
@@ -532,8 +537,9 @@
 {
 #if defined(_WIN_ALL)
   // CharLower is more reliable than towlower in Windows.
-  // See comment for towupper above.
-  return (int)(INT_PTR)CharLower((wchar *)(INT_PTR)ch);
+  // See comment for towupper above. Use 0xffff mask to prevent crash
+  // if value larger than 0xffff is passed to this function.
+  return (int)(INT_PTR)CharLower((wchar *)(INT_PTR)(ch&0xffff));
 #else
   return towlower(ch);
 #endif